@@ -1,7 +1,7 @@
 // qpwgraph_canvas.h
 //
 /****************************************************************************
-   Copyright (C) 2021-2024, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2021-2025, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -126,6 +126,8 @@ public:
 	void clearNodes(uint node_type);
 
 	// Special node finders.
+	qpwgraph_node *findNode(
+		const qpwgraph_node::NodeIdKey& node_key) const;
 	qpwgraph_node *findNode(
 		uint id, qpwgraph_item::Mode mode, uint type = 0) const;
 
@@ -157,6 +159,13 @@ public:
 	bool restoreState();
 	bool saveState() const;
 
+	// Graph node/port state methods.
+	bool restoreNode(qpwgraph_node *node);
+	bool saveNode(qpwgraph_node *node) const;
+
+	bool restorePort(qpwgraph_port *port);
+	bool savePort(qpwgraph_port *port) const;
+
 	// Repel overlapping nodes...
 	void setRepelOverlappingNodes(bool on);
 	bool isRepelOverlappingNodes() const;
@@ -198,6 +207,15 @@ public:
 
 	bool isFilterNodes(const QString& node_name) const;
 
+	// Merger/unify list management accessors.
+	void setMergerNodesEnabled(bool enabled);
+	bool isMergerNodesEnabled() const;
+
+	void setMergerNodesList(const QStringList& nodes);
+	const QStringList& mergerNodesList() const;
+
+	bool isMergerNodes(const QString& node_name) const;
+
 signals:
 
 	// Node factory notifications.
@@ -279,6 +297,9 @@ protected:
 	bool gestureEvent(QGestureEvent *event);
 	void pinchGesture(QPinchGesture *pinch);
 
+	// Node number if multiple (else count).
+	int nodeNum(qpwgraph_node *node) const;
+
 	// Graph node/port key helpers.
 	QString nodeKey(qpwgraph_node *node, int n = 0) const;
 	QString portKey(qpwgraph_port *port) const;
@@ -289,13 +310,6 @@ protected:
 	// Zoom in rectangle range.
 	void zoomFitRange(const QRectF& range_rect);
 
-	// Graph node/port state methods.
-	bool restoreNode(qpwgraph_node *node);
-	bool saveNode(qpwgraph_node *node) const;
-
-	bool restorePort(qpwgraph_port *port);
-	bool savePort(qpwgraph_port *port) const;
-
 	// Update editors position and size.
 	void updateRenameEditor();
 	void updateSearchEditor();
@@ -324,6 +338,7 @@ private:
 	QPointF           m_pos;
 	qpwgraph_item    *m_item;
 	qpwgraph_connect *m_connect;
+	qpwgraph_port    *m_port2;
 	QRubberBand      *m_rubberband;
 	qreal             m_zoom;
 	bool              m_zoomrange;
@@ -366,6 +381,10 @@ private:
 	// Filter/hide list management.
 	bool        m_filter_enabled;
 	QStringList m_filter_nodes;
+
+	// Merger/unify list management.
+	bool        m_merger_enabled;
+	QStringList m_merger_nodes;
 };
 
 
