@@ -494,18 +494,8 @@ qpwgraph_main::qpwgraph_main (
 
 	restoreState();
 
-	// Restore last open patchbay file...
 	m_patchbay_untitled = 0;
 
-	const QString path(m_patchbay_path);
-	if (!path.isEmpty() && patchbayOpenFile(path)) {
-		--m_patchbay_untitled;
-	} else {
-		qpwgraph_patchbay *patchbay = m_ui.graphCanvas->patchbay();
-		if (patchbay)
-			patchbay->snap(); // Simulate patchbayNew()!
-	}
-
 	updateViewColors();
 	updatePatchbayMenu();
 	updatePatchbayNames();
@@ -569,6 +559,16 @@ void qpwgraph_main::apply_args ( qpwgraph_application *app )
 	if (!app->patchbayPath().isEmpty())
 		m_patchbay_path = app->patchbayPath();
 
+	const QString path(m_patchbay_path);
+	if (path.isEmpty() || !patchbayOpenFile(path)) {
+		qpwgraph_patchbay *patchbay = m_ui.graphCanvas->patchbay();
+		if (patchbay)
+			patchbay->snap(); // Simulate patchbayNew()!
+		++m_patchbay_untitled;
+	}
+
+	updatePatchbayNames();
+
 	bool start_minimized = app->isStartMinimized();
 	if (!start_minimized)
 		start_minimized = m_config->isStartMinimized();
@@ -638,11 +638,24 @@ void qpwgraph_main::updateOptions (void)
 	m_ui.graphCanvas->setFilterNodesEnabled(m_config->isFilterNodesEnabled());
 	m_ui.graphCanvas->setFilterNodesList(m_config->filterNodesList());
 
+	m_ui.graphCanvas->setMergerNodesEnabled(m_config->isMergerNodesEnabled());
+	m_ui.graphCanvas->setMergerNodesList(m_config->mergerNodesList());
+
+	int nrefresh = 0;
+
 	if (m_config->isFilterNodesDirty()) {
 		m_config->setFilterNodesDirty(false);
-		viewRefresh();
+		++nrefresh;
 	}
 
+	if (m_config->isMergerNodesDirty()) {
+		m_config->setMergerNodesDirty(false);
+		++nrefresh;
+	}
+
+	if (nrefresh > 0)
+		viewRefresh();
+
 	stabilize();
 }
 
@@ -812,7 +825,11 @@ void qpwgraph_main::patchbayManage (void)
 {
 	qpwgraph_patchman patchman(this);
 	patchman.setPatchbay(m_ui.graphCanvas->patchbay());
+	if (m_config)
+		m_config->loadWidgetGeometry(&patchman);
 	patchman.exec();
+	if (m_config)
+		m_config->saveWidgetGeometry(&patchman);
 }
 
 
@@ -1070,7 +1087,7 @@ void qpwgraph_main::helpAbout (void)
 	text += "-static";
 #endif
 	text += ", ";
-	text +=	tr("libpipewire %1 (headers: %2)")
+	text +=	tr("PipeWire %1 (headers: %2)")
 		.arg(pw_get_library_version())
 		.arg(pw_get_headers_version());
 	text += "<br />\n";
@@ -1504,7 +1521,7 @@ bool qpwgraph_main::patchbaySaveFile ( const QString& path )
 QString qpwgraph_main::patchbayFileName (void) const
 {
 	if (m_patchbay_path.isEmpty())
-		return tr("Untitled%1").arg(m_patchbay_untitled + 1);
+		return tr("Untitled%1").arg(m_patchbay_untitled);
 	else
 		return QFileInfo(m_patchbay_path).completeBaseName();
 }
