@@ -1,7 +1,7 @@
 // qpwgraph_main.h
 //
 /****************************************************************************
-   Copyright (C) 2021-2024, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2021-2025, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -77,6 +77,9 @@ public:
 	// Update configure options.
 	void updateOptions();
 
+	// Current selected patchbay path accessor.
+	const QString& patchbayPath() const;
+
 protected slots:
 
 	// Node life-cycle slots
