@@ -1,7 +1,7 @@
 // qpwgraph_node.h
 //
 /****************************************************************************
-   Copyright (C) 2021-2024, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2021-2025, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -54,7 +54,7 @@ public:
 	uint nodeId() const;
 
 	void setNodeName(const QString& name);
-	const QString& nodeName() const;
+	QString nodeName() const;
 
 	void setNodeMode(Mode mode);
 	Mode nodeMode() const;
@@ -65,6 +65,9 @@ public:
 	void setNodeIcon(const QIcon& icon);
 	const QIcon& nodeIcon() const;
 
+	void setNodeNum(uint num);
+	uint nodeNum() const;
+
 	void setNodeLabel(const QString& label);
 	const QString& nodeLabel() const;
 	QString nodeNameLabel() const;
@@ -72,6 +75,13 @@ public:
 	void setNodeTitle(const QString& title);
 	const QString& nodeTitle() const;
 
+	void setNodePrefix(const QString& prefix);
+	const QString& nodePrefix() const;
+
+	void setNodeNameEx(bool name_ex);
+	bool isNodeNameEx() const;
+	QString nodeNameEx() const;
+
 	// Port-list methods.
 	qpwgraph_port *addPort(uint id, const QString& name, Mode mode, int type = 0);
 
@@ -115,7 +125,7 @@ public:
 		NodeNameKey (const QString& name, Mode mode, uint type = 0)
 			: NameKey(name, mode, type) {}
 		NodeNameKey(qpwgraph_node *node)
-			: NameKey(node->nodeName(), node->nodeMode(), node->nodeType()) {}
+			: NameKey(node->nodeNameEx(), node->nodeMode(), node->nodeType()) {}
 	};
 
 	typedef QMultiHash<NodeNameKey, qpwgraph_node *> NodeNames;
@@ -139,9 +149,14 @@ private:
 	uint    m_type;
 
 	QIcon   m_icon;
+	uint    m_num;
 	QString m_label;
 	QString m_title;
 
+	QString m_prefix;
+
+	bool m_name_ex;
+
 	QGraphicsPixmapItem *m_pixmap;
 	QGraphicsTextItem   *m_text;
 
