@@ -133,6 +133,7 @@ struct qpwgraph_pipewire::Node : public qpwgraph_pipewire::Object
 	qpwgraph_item::Mode node_mode;
 	NodeType node_type;
 	QList<qpwgraph_pipewire::Port *> node_ports;
+	qpwgraph_item::Mode node_mode2;
 	QIcon node_icon;
 	QString media_name;
 	bool node_changed;
@@ -259,27 +260,8 @@ void qpwgraph_node_event_info ( void *data, const struct pw_node_info *info )
 					node->node_icon = node_icon;
 				const char *media_name
 					= spa_dict_lookup(info->props, PW_KEY_MEDIA_NAME);
-				if (media_name && ::strlen(media_name) > 0) {
+				if (media_name && ::strlen(media_name) > 0)
 					node->media_name = media_name;
-					if (node->node_nick.isEmpty()) {
-						qpwgraph_pipewire *pw = nullptr;
-						if (node->p)
-							pw = (node->p)->pw;
-						qpwgraph_pipewire::Data::NodeNames *node_names = nullptr;
-						if (pw && pw->data())
-							node_names = (pw->data())->node_names;
-						if (node_names) {
-							node_names->remove(
-								qpwgraph_pipewire::Node::NameKey(node),
-								node->name_num);
-							node->node_name = node->media_name;
-							node->media_name.clear();
-							node_names->insert(
-								qpwgraph_pipewire::Node::NameKey(node),
-								node->name_num);
-						}
-					}
-				}
 				node->node_changed = true;
 				node->node_ready = true;
 				if (object->p->pw)
@@ -986,7 +968,7 @@ bool qpwgraph_pipewire::findNodePort (
 	const uint node_type
 		= qpwgraph_pipewire::nodeType();
 	qpwgraph_item::Mode node_mode
-		= port_mode;
+		= port_mode;//n->node_mode2;
 	const uint port_type
 		= p->port_type;
 
@@ -998,14 +980,11 @@ bool qpwgraph_pipewire::findNodePort (
 		const uint port_flags_mask
 			= (Port::Physical | Port::Terminal);
 		if ((port_flags & port_flags_mask) != port_flags_mask) {
-			node_mode = qpwgraph_item::Duplex;
+			node_mode = n->node_mode2;//qpwgraph_item::Duplex;
 			*node = qpwgraph_sect::findNode(node_id, node_mode, node_type);
 		}
 	}
 
-	if (*node && m_recycled_nodes.value(qpwgraph_node::NodeIdKey(*node), nullptr))
-		return false;
-
 	if (*node && n->node_changed) {
 		canvas->releaseNode(*node);
 		*node = nullptr;
@@ -1014,16 +993,9 @@ bool qpwgraph_pipewire::findNodePort (
 	if (*node)
 		*port = (*node)->findPort(port_id, port_mode, port_type);
 
-	if (*port && m_recycled_ports.value(qpwgraph_port::PortIdKey(*port), nullptr))
-		return false;
-
 	if (add_new && *node == nullptr && !canvas->isFilterNodes(n->node_name)) {
 		QString node_name = n->node_name;
 		if ((p->port_flags & Port::Physical) == Port::None) {
-			if (n->name_num > 0) {
-				node_name += '-';
-				node_name += QString::number(n->name_num);
-			}
 			if (p->port_flags & Port::Monitor) {
 				node_name += ' ';
 				node_name += "[Monitor]";
@@ -1035,8 +1007,10 @@ bool qpwgraph_pipewire::findNodePort (
 		}
 		*node = new qpwgraph_node(node_id, node_name, node_mode, node_type);
 		(*node)->setNodeIcon(n->node_icon);
+		(*node)->setNodeNum(n->name_num);
 		(*node)->setNodeLabel(n->media_name);
 		(*node)->setNodePrefix(n->node_nick);
+		(*node)->setNodeNameEx(canvas->isMergerNodes(node_name));
 		n->node_changed = false;
 		qpwgraph_sect::addItem(*node);
 	}
@@ -1131,9 +1105,6 @@ void qpwgraph_pipewire::updateItems (void)
 	// 3. Clean-up all un-marked items...
 	//
 	qpwgraph_sect::resetItems(qpwgraph_pipewire::nodeType());
-
-	m_recycled_nodes.clear();
-	m_recycled_ports.clear();
 }
 
 
@@ -1150,9 +1121,6 @@ void qpwgraph_pipewire::clearItems (void)
 	// Clean-up all items...
 	//
 	qpwgraph_sect::clearItems(qpwgraph_pipewire::nodeType());
-
-	m_recycled_nodes.clear();
-	m_recycled_ports.clear();
 }
 
 
@@ -1273,18 +1241,18 @@ qpwgraph_pipewire::Node *qpwgraph_pipewire::createNode (
 	qpwgraph_item::Mode node_mode,
 	uint node_type )
 {
-	recycleNode(node_id, node_mode);
-
 	Node *node = new Node(node_id);
 	node->node_name = node_name;
 	node->node_nick = node_nick;
 	node->node_mode = node_mode;
 	node->node_type = Node::NodeType(node_type);
+	node->node_mode2 = node_mode;
 	node->node_icon = qpwgraph_icon(":/images/itemPipewire.png");
 	node->node_changed = false;
 	node->node_ready = false;
 	node->name_num = 0;
 
+
 	Data::NodeNames *node_names = nullptr;
 	if (m_data)
 		node_names = m_data->node_names;
@@ -1337,8 +1305,6 @@ qpwgraph_pipewire::Port *qpwgraph_pipewire::createPort (
 	uint port_type,
 	uint port_flags )
 {
-	recyclePort(port_id, node_id, port_mode, port_type);
-
 	Node *node = findNode(node_id);
 	if (node == nullptr)
 		return nullptr;
@@ -1353,7 +1319,11 @@ qpwgraph_pipewire::Port *qpwgraph_pipewire::createPort (
 	if (port->port_type == midi2PortType())
 		port->port_type =  midiPortType();	// FIXME: legacy aliasing!...
 
+	if ((node->node_mode2 & port_mode) == qpwgraph_item::None)
+		node->node_mode2 = qpwgraph_item::Duplex;
+
 	node->node_ports.append(port);
+	node->node_changed = true;
 
 	addObjectEx(port_id, port);
 
@@ -1372,6 +1342,7 @@ void qpwgraph_pipewire::destroyPort ( Port *port )
 
 	port->port_links.clear();
 	node->node_ports.removeAll(port);
+	node->node_changed = true;
 
 	delete port;
 }
@@ -1438,27 +1409,4 @@ qpwgraph_node *qpwgraph_pipewire::findNode (
 }
 
 
-// Special node recycler...
-void qpwgraph_pipewire::recycleNode (
-	uint node_id, qpwgraph_item::Mode node_mode )
-{
-	qpwgraph_node *node = findNode(node_id, node_mode);
-	if (node)
-		m_recycled_nodes.insert(qpwgraph_node::NodeIdKey(node), node);
-}
-
-
-// Special port recycler...
-void qpwgraph_pipewire::recyclePort (
-	uint port_id, uint node_id, qpwgraph_item::Mode port_mode, uint port_type )
-{
-	qpwgraph_node *node = findNode(node_id, port_mode);
-	if (node) {
-		qpwgraph_port *port = node->findPort(port_id, port_mode, port_type);
-		if (port)
-			m_recycled_ports.insert(qpwgraph_port::PortIdKey(port), port);
-	}
-}
-
-
 // end of qpwgraph_pipewire.cpp
